What Makes a Good Wordlist?
===========================

Wordlists are considered "good" if they are

- Short (in terms of average word width)
- Long  (in terms of number of words)
- international (understandable by foreigners)
- typable (on an ASCII-only keyboard)
- unique (no double terms)
- Friendly (non-offensive)
- memorizable:
  - well-known (words known by average speakers)
  - non-confusable ("412", "421" are easily confused)


- contain enough terms for use with a certain diceware application
  (for instance 6^6 = 7776 terms if used with six dice)
- contain terms as short as possible (to reduce typing)
- (optionally) contain no words with non-ASCII chars (to enable use
  with non-localized keyboards)
- contain no offending terms
